@@ -2,7 +2,7 @@
     This class provides a container for the authentication data.
                              -------------------
     begin                : Sa Feb 28 2004
-    copyright            : (C) 2004-2017 by Alexander Reinholdt
+    copyright            : (C) 2004-2019 by Alexander Reinholdt
     email                : alexander.reinholdt@kdemail.net
  ***************************************************************************/
 
@@ -29,11 +29,16 @@
 
 // application specific includes
 #include "smb4kauthinfo.h"
+#include "smb4khost.h"
+#include "smb4kshare.h"
 
 // Qt includes
 #include <QHostAddress>
 #include <QDebug>
 
+// KDE includes
+#include <KI18n/KLocalizedString>
+
 
 class Smb4KAuthInfoPrivate
 {
@@ -46,40 +51,53 @@ class Smb4KAuthInfoPrivate
 };
 
 
-Smb4KAuthInfo::Smb4KAuthInfo(const Smb4KHost *host)
+Smb4KAuthInfo::Smb4KAuthInfo(Smb4KBasicNetworkItem* item)
 : d(new Smb4KAuthInfoPrivate)
 {
-  d->url        = host->url();
-  d->type       = Host;
-  d->workgroup  = host->workgroupName();
-  d->homesShare = false;
-  d->ip.setAddress(host->ip());
-}
+  d->type = item->type();
 
-
-Smb4KAuthInfo::Smb4KAuthInfo(const Smb4KShare *share)
-: d(new Smb4KAuthInfoPrivate)
-{
-  if (!share->isHomesShare())
+  switch (d->type)
   {
-    d->url      = share->url();
+    case Host:
+    {
+      Smb4KHost *host = static_cast<Smb4KHost *>(item);
+      
+      if (host)
+      {
+        d->url = host->url();
+        d->workgroup = host->workgroupName();
+        d->homesShare = false;
+        d->ip.setAddress(host->ipAddress());
+      }
+      
+      break;
+    }
+    case Share:
+    {
+      Smb4KShare *share = static_cast<Smb4KShare *>(item);
+      
+      if (share)
+      {
+        d->url = !share->isHomesShare() ? share->homeUrl() : share->url();
+        d->workgroup = share->workgroupName();
+        d->homesShare = share->isHomesShare();
+        d->ip.setAddress(share->hostIpAddress());
+      }
+      
+      break;
+    }
+    default:
+    {
+      break;
+    }
   }
-  else
-  {
-    d->url      = share->homeURL();
-  }
-
-  d->type       = Share;
-  d->workgroup  = share->workgroupName();
-  d->homesShare = share->isHomesShare();
-  d->ip.setAddress(share->hostIP());
 }
 
 
 Smb4KAuthInfo::Smb4KAuthInfo()
 : d(new Smb4KAuthInfoPrivate)
 {
-  d->type       = UnknownNetworkItem;
+  d->type = UnknownNetworkItem;
   d->homesShare = false;
   d->url.clear();
   d->workgroup.clear();
@@ -99,52 +117,6 @@ Smb4KAuthInfo::~Smb4KAuthInfo()
 }
 
 
-void Smb4KAuthInfo::setHost(Smb4KHost *host)
-{
-  Q_ASSERT(host);
-  
-  if (host)
-  {
-    d->url        = host->url();
-    d->type       = Host;
-    d->workgroup  = host->workgroupName();
-    d->homesShare = false;
-    d->ip.setAddress(host->ip());
-  }
-  else
-  {
-    // Do nothing
-  }
-}
-
-
-void Smb4KAuthInfo::setShare(Smb4KShare *share)
-{
-  Q_ASSERT(share);
-  
-  if (share)
-  {
-    if (!share->isHomesShare())
-    {
-      d->url      = share->url();
-    }
-    else
-    {
-      d->url      = share->homeURL();
-    }
-    
-    d->type       = Share;
-    d->workgroup  = share->workgroupName();
-    d->homesShare = share->isHomesShare();
-    d->ip.setAddress(share->hostIP());
-  }
-  else
-  {
-    // Do nothing
-  }
-}
-
-
 void Smb4KAuthInfo::setWorkgroupName(const QString &workgroup)
 {
   d->workgroup = workgroup;
@@ -157,64 +129,7 @@ QString Smb4KAuthInfo::workgroupName() const
 }
 
 
-QString Smb4KAuthInfo::unc() const
-{
-  QString unc;
-  
-  switch (d->type)
-  {
-    case Host:
-    {
-      if (!hostName().isEmpty())
-      {
-        unc = QString("//%1").arg(hostName());
-      }
-      else
-      {
-        // Do nothing
-      }
-      break;
-    }
-    case Share:
-    {
-      if (!hostName().isEmpty() && !shareName().isEmpty())
-      {
-        unc = QString("//%1/%2").arg(hostName()).arg(shareName());
-      }
-      else
-      {
-        // Do nothing
-      }
-      break;
-    }
-    default:
-    {
-      break;
-    }
-  }
-
-  return unc;
-}
-
-
-QString Smb4KAuthInfo::hostUNC() const
-{
-  QString unc;
-  
-  if (!hostName().isEmpty())
-  {
-    unc = QString("//%1").arg(hostName());
-  }
-  else
-  {
-    // Do nothing
-  }
-  
-  return unc;
-}
-
-
-void Smb4KAuthInfo::setURL(const QUrl &url)
+void Smb4KAuthInfo::setUrl(const QUrl &url)
 {
   d->url = url;
   d->url.setScheme("smb");
@@ -230,29 +145,15 @@ void Smb4KAuthInfo::setURL(const QUrl &url)
   }
   
   // Determine whether this is a homes share.
-  qDebug() << "Smb4KAuthInfo::setURL(): Check if determination of homes share works";
-  d->homesShare = (QString::compare(d->url.path().remove(0, 1), "homes", Qt::CaseSensitive) == 0);
+  d->homesShare = (QString::compare(d->url.path().remove('/'), "homes", Qt::CaseSensitive) == 0);
 }
 
 
-void Smb4KAuthInfo::setURL(const QString &url)
+void Smb4KAuthInfo::setUrl(const QString &url)
 {
-  d->url.setUrl(url, QUrl::TolerantMode);
-  d->url.setScheme("smb");
-  
-  // Set the type.
-  if (!d->url.path().isEmpty() && d->url.path().length() > 1 && !d->url.path().endsWith('/'))
-  {
-    d->type = Share;
-  }
-  else
-  {
-    d->type = Host;
-  }
-  
-  // Determine whether this is a homes share.
-  qDebug() << "Smb4KAuthInfo::setURL(): Check if determination of homes share works";
-  d->homesShare = (QString::compare(d->url.path().remove(0, 1), "homes", Qt::CaseSensitive) == 0);
+  QUrl tempUrl(url, QUrl::TolerantMode);
+  tempUrl.setScheme("smb");
+  setUrl(tempUrl);
 }
 
 
@@ -276,10 +177,6 @@ QString Smb4KAuthInfo::shareName() const
   {
     return d->url.path().remove(0, 1);
   }
-  else
-  {
-    // Do nothing
-  }
 
   return d->url.path();
 }
@@ -293,10 +190,6 @@ void Smb4KAuthInfo::setUserName(const QString &username)
   {
     d->url.setPath(username);
   }
-  else
-  {
-    // Do nothing
-  }
 }
 
 
@@ -330,70 +223,21 @@ bool Smb4KAuthInfo::isHomesShare() const
 }
 
 
-bool Smb4KAuthInfo::equals(Smb4KAuthInfo *info) const
-{
-  // URL
-  if (d->url != info->url())
-  {
-    return false;
-  }
-  else
-  {
-    // Do nothing
-  }
-  
-  // Type
-  if (d->type != info->type())
-  {
-    return false;
-  }
-  else
-  {
-    // Do nothing
-  }
-  
-  // Workgroup
-  if (QString::compare(d->workgroup, info->workgroupName(), Qt::CaseInsensitive) != 0)
-  {
-    return false;
-  }
-  else
-  {
-    // Do nothing
-  }
-  
-  // Homes share?
-  if (d->homesShare != info->isHomesShare())
-  {
-    return false;
-  }
-  else
-  {
-    // Do nothing
-  }
-
-  // IP address
-  if (QString::compare(d->ip.toString(), info->ip()) != 0)
-  {
-    return false;
-  }
-  else
-  {
-    // Do nothing
-  }
-  
-  return true;
-}
-
-
-void Smb4KAuthInfo::setIP(const QString &ip)
+void Smb4KAuthInfo::setIpAddress(const QString &ip)
 {
   d->ip.setAddress(ip);
 }
 
 
-QString Smb4KAuthInfo::ip() const
+QString Smb4KAuthInfo::ipAddress() const
 {
   return d->ip.toString();
 }
 
+
+QString Smb4KAuthInfo::displayString() const
+{
+  return i18n("%1 on %2", shareName(), hostName());
+}
+
+
