@@ -2,7 +2,7 @@
     This file contains private helper classes for the Smb4KMounter class.
                              -------------------
     begin                : Do Jul 19 2007
-    copyright            : (C) 2007-2017 by Alexander Reinholdt
+    copyright            : (C) 2007-2019 by Alexander Reinholdt
     email                : alexander.reinholdt@kdemail.net
  ***************************************************************************/
 
@@ -36,6 +36,7 @@
 #include <QCheckBox>
 #include <QDialog>
 #include <QPushButton>
+#include <QPointer>
 
 // KDE includes
 #include <KCompletion/KLineEdit>
@@ -52,8 +53,8 @@ class Smb4KMountDialog : public QDialog
      *
      * @param parent      The parent widget
      */
-    explicit Smb4KMountDialog(const SharePtr &share,
-                              QWidget *parent = 0);
+    explicit Smb4KMountDialog(const SharePtr &share, QWidget *parent = 0);
+    
     /**
      * The destructor.
      */
@@ -167,7 +168,7 @@ class Smb4KMounterPrivate
     int checkTimeout;
     int newlyMounted;
     int newlyUnmounted;
-    Smb4KMountDialog *dialog;
+    QPointer<Smb4KMountDialog> dialog;
     QList<SharePtr> importedShares;
     QList<SharePtr> retries;
     QList<SharePtr> remounts;
