@@ -2,7 +2,7 @@
     The configuration page for the authentication settings of Smb4K
                              -------------------
     begin                : Sa Nov 15 2003
-    copyright            : (C) 2003-2017 by Alexander Reinholdt
+    copyright            : (C) 2003-2019 by Alexander Reinholdt
     email                : alexander.reinholdt@kdemail.net
  ***************************************************************************/
 
@@ -31,16 +31,8 @@
 
 // Qt includes
 #include <QList>
-#include <QTableWidget>
-#include <QCheckBox>
-#include <QPushButton>
-#include <QTabWidget>
 #include <QListWidget>
 
-// KDE includes
-#include <KWidgetsAddons/KActionMenu>
-#include <KXmlGui/KActionCollection>
-
 /**
  * This is the configuration tab for the authentication settings
  * of Smb4K.
@@ -49,17 +41,11 @@
  */
 
 
-class Smb4KConfigPageAuthentication : public QTabWidget
+class Smb4KConfigPageAuthentication : public QWidget
 {
   Q_OBJECT
 
   public:
-    /**
-     * Tabs enumeration
-     */
-    enum Tabs{ GeneralTab = 0,
-               WalletEntriesTab = 1 };
-               
     /**
      * The constructor.
      *
@@ -86,13 +72,7 @@ class Smb4KConfigPageAuthentication : public QTabWidget
      * 
      * @returns the list of entries.
      */
-    const QList<Smb4KAuthInfo *> &getWalletEntries() { return m_entries_list; }
-    
-    /**
-     * Display the autentication information in the list widget.
-     * Use this function AFTER setEntries() if necessary.
-     */
-    void displayWalletEntries();
+    const QList<Smb4KAuthInfo *> &getWalletEntries() { return m_entriesList; }
     
     /**
      * Returns TRUE if the wallet entries are displayed and FALSE otherwise.
@@ -101,14 +81,6 @@ class Smb4KConfigPageAuthentication : public QTabWidget
      */
     bool walletEntriesDisplayed() { return m_entries_displayed; }
     
-    /**
-     * Returns TRUE if a removal in the list widget is undone and FALSE
-     * otherwise.
-     * 
-     * @returns TRUE a removal is undown.
-     */
-    bool undoRemoval() { return m_undo_removal; }
-    
     /**
      * Returns TRUE in the case the wallet entries might have changed. You need
      * to check this outside this widget, whether a change indeed occurred.
@@ -145,8 +117,7 @@ class Smb4KConfigPageAuthentication : public QTabWidget
     /**
      * Reimplemented.
      */
-    bool eventFilter(QObject *object,
-                     QEvent *event);
+    bool eventFilter(QObject *object, QEvent *event) override;
     
   protected slots:
     /**
@@ -165,14 +136,6 @@ class Smb4KConfigPageAuthentication : public QTabWidget
      */
     void slotDefaultLoginToggled(bool checked);
     
-    /**
-     * This slot is connected to the "Details" button and shows the details
-     * of the selected wallet entry.
-     * 
-     * @param checked       TRUE if the button is checked
-     */
-    void slotDetailsClicked(bool checked);
-    
     /**
      * This slot is connected to the KListWidget::itemSelectionChanged() signal.
      * It unmarks and enables/disables the "Show details" checkbox and clears the
@@ -189,55 +152,22 @@ class Smb4KConfigPageAuthentication : public QTabWidget
      * 
      * @param column          The column of the cell that was changed
      */
-    void slotDetailsChanged(int row,
-                             int column);
+    void slotDetailsChanged(int row, int column);
     
     /**
-     * This slot is connected to the KListWidget::customContextMenuRequested()
-     * signal and shows the menu in the list widget.
+     * This slot is called when the edit action is clicked.
      */
-    void slotShowListWidgetContextMenu(const QPoint &pos);
+    void slotEditClicked();
     
     /**
-     * This slot is connected to the QTableWidget::customContextMenuRequested()
-     * signal and shows the menu in the table widget.
+     * This slot is connected to the "Remove" button
      */
-    void slotShowTableWidgetContextMenu(const QPoint &pos);
+    void slotRemoveClicked();
     
     /**
-     * This slot is connected to the "Remove" action
-     * 
-     * @param checked         TRUE if the action is checked
+     * This slot is connected to the "Clear" button
      */
-    void slotRemoveActionTriggered(bool checked);
-    
-    /**
-     * This slot is connected to the "Clear List" action
-     * 
-     * @param checked         TRUE if the action is checked
-     */
-    void slotClearActionTriggered(bool checked);
-    
-    /**
-     * This slot is connected to the "Undo" action in the list widget.
-     * 
-     * @param checked         TRUE if the action is checked
-     */
-    void slotUndoListActionTriggered(bool checked);
-    
-    /**
-     * This slot is connected to the "Edit" action in the table widget.
-     * 
-     * @param checked         TRUE if the action is checked
-     */
-    void slotEditActionTriggered(bool checked);
-    
-    /**
-     * This slot is connected to the "Undo" action in the table widget.
-     * 
-     * @param checked         TRUE if the action is checked
-     */
-    void slotUndoDetailsActionTriggered(bool checked);
+    void slotClearClicked();
     
     /**
      * This slot is connected to the "Save" button and resets all actions.
@@ -247,22 +177,10 @@ class Smb4KConfigPageAuthentication : public QTabWidget
     void slotSaveClicked(bool checked);
     
   private:
-    void showDetails(Smb4KAuthInfo *authInfo);
+    void loadDetails(Smb4KAuthInfo *authInfo);
     void clearDetails();
-    QListWidget *m_entries_widget;
-    QPushButton *m_load_button;
-    QPushButton *m_save_button;
-    QCheckBox *m_details_box;
-    QTableWidget *m_details_widget;
-    QList<Smb4KAuthInfo *> m_entries_list;
+    QList<Smb4KAuthInfo *> m_entriesList;
     bool m_entries_displayed;
-    KActionCollection *m_collection;
-    KActionMenu *m_entries_menu;
-    KActionMenu *m_details_menu;
-    Smb4KAuthInfo *m_auth_info;
-    bool m_loading_details;
-    bool m_default_login;
-    bool m_undo_removal;
     bool m_maybe_changed;
 };
 
