@@ -62,6 +62,8 @@ Smb4KToolTip::Smb4KToolTip(QWidget* parent)
 : QWidget(parent, Qt::ToolTip|Qt::BypassGraphicsProxyWidget|Qt::FramelessWindowHint),
   m_item(NetworkItemPtr()), m_tip_layout(0), m_info_layout(0), m_text_layout(0)
 {
+  qDebug() << "Use KToolTipWidget for the tooltips";
+  
   m_master_browser_label = 0;
   m_comment_label        = 0;
   m_ip_label             = 0;
@@ -111,10 +113,6 @@ void Smb4KToolTip::setup(Smb4KToolTip::Parent parent, const NetworkItemPtr &item
       }
     }
   }
-  else
-  {
-    // Do nothing
-  }
 }
 
 
@@ -134,9 +132,9 @@ void Smb4KToolTip::update(Smb4KToolTip::Parent parent, const NetworkItemPtr &ite
           {
             WorkgroupPtr workgroup = item.staticCast<Smb4KWorkgroup>();
             
-            if (!workgroup->masterBrowserIP().isEmpty())
+            if (workgroup->hasMasterBrowserIpAddress())
             {
-              m_master_browser_label->setText(workgroup->masterBrowserName()+" ("+workgroup->masterBrowserIP()+')');
+              m_master_browser_label->setText(workgroup->masterBrowserName()+" ("+workgroup->masterBrowserIpAddress()+')');
             }
             else
             {
@@ -157,9 +155,9 @@ void Smb4KToolTip::update(Smb4KToolTip::Parent parent, const NetworkItemPtr &ite
               m_comment_label->setText("-");
             }
             
-            if (!host->ip().isEmpty())
+            if (host->hasIpAddress())
             {
-              m_ip_label->setText(host->ip());
+              m_ip_label->setText(host->ipAddress());
             }
             else
             {
@@ -196,9 +194,9 @@ void Smb4KToolTip::update(Smb4KToolTip::Parent parent, const NetworkItemPtr &ite
               m_mounted_label->setText("-");
             }
             
-            if (!share->hostIP().isEmpty())
+            if (share->hasHostIpAddress())
             {
-              m_ip_label->setText(share->hostIP());
+              m_ip_label->setText(share->hostIpAddress());
             }
             else
             {
@@ -237,10 +235,6 @@ void Smb4KToolTip::update(Smb4KToolTip::Parent parent, const NetworkItemPtr &ite
       }
     }    
   }
-  else
-  {
-    // Do nothing
-  }
 }
 
  
@@ -343,9 +337,9 @@ void Smb4KToolTip::setupNetworkBrowserToolTip()
       
       m_text_layout->addWidget(mb_label, 1, 0, Qt::AlignRight);
       
-      if (!workgroup->masterBrowserIP().isEmpty())
+      if (workgroup->hasMasterBrowserIpAddress())
       {
-        m_master_browser_label = new QLabel(workgroup->masterBrowserName()+" ("+workgroup->masterBrowserIP()+')', this);
+        m_master_browser_label = new QLabel(workgroup->masterBrowserName()+" ("+workgroup->masterBrowserIpAddress()+')', this);
         m_text_layout->addWidget(m_master_browser_label, 1, 1, 0);
       }
       else
@@ -400,9 +394,9 @@ void Smb4KToolTip::setupNetworkBrowserToolTip()
       
       m_text_layout->addWidget(ip_label, 2, 0, Qt::AlignRight);
       
-      if (!host->ip().isEmpty())
+      if (host->hasIpAddress())
       {
-        m_ip_label = new QLabel(host->ip(), this);
+        m_ip_label = new QLabel(host->ipAddress(), this);
         m_text_layout->addWidget(m_ip_label, 2, 1, 0);
       }
       else
@@ -440,7 +434,7 @@ void Smb4KToolTip::setupNetworkBrowserToolTip()
       type_label->setPalette(p);
       
       m_text_layout->addWidget(type_label, 0, 0, Qt::AlignRight);
-      m_text_layout->addWidget(new QLabel(i18n("Share (%1)", share->translatedTypeString()), this), 0, 1, 0);
+      m_text_layout->addWidget(new QLabel(i18n("Share (%1)", share->shareTypeString()), this), 0, 1, 0);
       
       QLabel *co_label = new QLabel(i18n("Comment"), this);
       co_label->setPalette(p);
@@ -493,9 +487,9 @@ void Smb4KToolTip::setupNetworkBrowserToolTip()
       
       m_text_layout->addWidget(ip_label, 4, 0, Qt::AlignRight);
       
-      if (!share->hostIP().isEmpty())
+      if (share->hasHostIpAddress())
       {
-        m_ip_label = new QLabel(share->hostIP(), this);
+        m_ip_label = new QLabel(share->hostIpAddress(), this);
         m_text_layout->addWidget(m_ip_label, 4, 1, 0);
       }
       else
@@ -504,11 +498,11 @@ void Smb4KToolTip::setupNetworkBrowserToolTip()
         m_text_layout->addWidget(m_ip_label, 4, 1, 0);
       }
       
-      QLabel *unc_label = new QLabel(i18n("UNC"), this);
+      QLabel *unc_label = new QLabel(i18n("Location"), this);
       unc_label->setPalette(p);
       
       m_text_layout->addWidget(unc_label, 5, 0, Qt::AlignRight);
-      m_text_layout->addWidget(new QLabel(share->unc(), this), 5, 1, 0);
+      m_text_layout->addWidget(new QLabel(share->displayString(), this), 5, 1, 0);
       
       m_info_layout->addLayout(m_text_layout);
       m_info_layout->addSpacerItem(new QSpacerItem(0, 0, QSizePolicy::Minimum, QSizePolicy::Expanding));
@@ -564,11 +558,11 @@ void Smb4KToolTip::setupSharesViewToolTip()
       
   m_text_layout = new QGridLayout();
       
-  QLabel *unc_label = new QLabel(i18n("UNC"), this);
+  QLabel *unc_label = new QLabel(i18n("Location"), this);
   unc_label->setPalette(p);
       
   m_text_layout->addWidget(unc_label, 0, 0, Qt::AlignRight);
-  m_text_layout->addWidget(new QLabel(share->unc(), this), 0, 1, 0);
+  m_text_layout->addWidget(new QLabel(share->displayString(), this), 0, 1, 0);
       
   QLabel *mp_label = new QLabel(i18n("Mountpoint"), this);
   mp_label->setPalette(p);
@@ -647,19 +641,15 @@ void Smb4KToolTip::updateNetworkBrowserToolTip()
         
         if (mb_label)
         {
-          if (!workgroup->hasMasterBrowserIP())
+          if (!workgroup->hasMasterBrowserIpAddress())
           {
-            mb_label->setText(workgroup->masterBrowserName()+" ("+workgroup->masterBrowserIP()+')');
+            mb_label->setText(workgroup->masterBrowserName()+" ("+workgroup->masterBrowserIpAddress()+')');
           }
           else
           {
             mb_label->setText(workgroup->masterBrowserName());
           }
         }
-        else
-        {
-          // Do nothing
-        }
         
         break;
       }
@@ -682,10 +672,6 @@ void Smb4KToolTip::updateNetworkBrowserToolTip()
             co_label->setText("-");
           }
         }
-        else
-        {
-          // Do nothing
-        }
       
         // IP address
         QLayoutItem *ip_item = m_text_layout->itemAtPosition(2, 1);
@@ -693,19 +679,15 @@ void Smb4KToolTip::updateNetworkBrowserToolTip()
         
         if (ip_label)
         {
-          if (!host->ip().isEmpty())
+          if (host->hasIpAddress())
           {
-            ip_label->setText(host->ip());
+            ip_label->setText(host->ipAddress());
           }
           else
           {
             ip_label->setText("-");
           }
         }
-        else
-        {
-          // Do nothing
-        }
       
         break;
       }
@@ -733,10 +715,6 @@ void Smb4KToolTip::updateNetworkBrowserToolTip()
             co_label->setText("-");
           }
         }
-        else
-        {
-          // Do nothing
-        }
      
         // Mounted indicator
         QLayoutItem *mnt_item = m_text_layout->itemAtPosition(2, 1);
@@ -760,10 +738,6 @@ void Smb4KToolTip::updateNetworkBrowserToolTip()
             mnt_label->setText("-");
           }
         }
-        else
-        {
-          // Do nothing
-        }
         
         // The rest won't change while the tool tip is shown.
       
@@ -775,10 +749,6 @@ void Smb4KToolTip::updateNetworkBrowserToolTip()
       }
     }
   }
-  else
-  {
-    // Do nothing
-  }
 }
 
 
@@ -820,10 +790,6 @@ void Smb4KToolTip::updateSharesViewToolTip()
       s_label->setText(i18n("unknown"));
     }
   }
-  else
-  {
-    // Do nothing
-  }
   
   // The rest won't change while the tool tip is shown.
 }
@@ -848,10 +814,6 @@ void Smb4KToolTip::paintEvent(QPaintEvent *e)
     toColor.setAlpha(220);
     fromColor.setAlpha(220);
   }
-  else
-  {
-    // Do nothing
-  }
 
   QLinearGradient gradient(QPointF(0.0, 0.0), QPointF(0.0, height()));
   gradient.setColorAt(0.0, fromColor);
